# frozen_string_literal: true

require_relative "sanqi/game"

# Sanqi namespace.
module Sanqi
  AUTHORIZED_OCCURRENCE_OF_POSITION = 2
  SQUARE_COUNT = 64

  VARIANTS = %i[
    CHESS
    PUCHI_SHOGI
    XIAOQI
  ].freeze

  CHESS_VS_CHESS_SQUARE = {
    0  => "c:r",
    1  => "c:n",
    2  => "c:b",
    3  => "c:q",
    4  => "c:-k",
    5  => "c:b",
    6  => "c:n",
    7  => "c:r",
    8  => "c:p",
    9  => "c:p",
    10 => "c:p",
    11 => "c:p",
    12 => "c:p",
    13 => "c:p",
    14 => "c:p",
    15 => "c:p",

    48 => "C:P",
    49 => "C:P",
    50 => "C:P",
    51 => "C:P",
    52 => "C:P",
    53 => "C:P",
    54 => "C:P",
    55 => "C:P",
    56 => "C:R",
    57 => "C:N",
    58 => "C:B",
    59 => "C:Q",
    60 => "C:-K",
    61 => "C:B",
    62 => "C:N",
    63 => "C:R"
  }.freeze

  CHESS_VS_PUCHI_SHOGI_SQUARE = {
    0  => "s:r",
    1  => "s:n",
    2  => "s:b",
    3  => "s:q",
    4  => "s:-k",
    5  => "s:b",
    6  => "s:n",
    7  => "s:r",
    8  => "s:p",
    9  => "s:p",
    10 => "s:p",
    11 => "s:p",
    12 => "s:p",
    13 => "s:p",
    14 => "s:p",
    15 => "s:p",

    48 => "C:P",
    49 => "C:P",
    50 => "C:P",
    51 => "C:P",
    52 => "C:P",
    53 => "C:P",
    54 => "C:P",
    55 => "C:P",
    56 => "C:R",
    57 => "C:N",
    58 => "C:B",
    59 => "C:Q",
    60 => "C:-K",
    61 => "C:B",
    62 => "C:N",
    63 => "C:R"
  }.freeze

  CHESS_VS_XIAOQI_SQUARE = {
    0  => "x:r",
    1  => "x:n",
    2  => "x:b",
    3  => "x:q",
    4  => "x:-k",
    5  => "x:b",
    6  => "x:n",
    7  => "x:r",
    8  => "x:p",
    9  => "x:p",
    10 => "x:p",
    11 => "x:p",
    12 => "x:p",
    13 => "x:p",
    14 => "x:p",
    15 => "x:p",

    48 => "C:P",
    49 => "C:P",
    50 => "C:P",
    51 => "C:P",
    52 => "C:P",
    53 => "C:P",
    54 => "C:P",
    55 => "C:P",
    56 => "C:R",
    57 => "C:N",
    58 => "C:B",
    59 => "C:Q",
    60 => "C:-K",
    61 => "C:B",
    62 => "C:N",
    63 => "C:R"
  }.freeze

  PUCHI_SHOGI_VS_CHESS_SQUARE = {
    0  => "c:r",
    1  => "c:n",
    2  => "c:b",
    3  => "c:q",
    4  => "c:-k",
    5  => "c:b",
    6  => "c:n",
    7  => "c:r",
    8  => "c:p",
    9  => "c:p",
    10 => "c:p",
    11 => "c:p",
    12 => "c:p",
    13 => "c:p",
    14 => "c:p",
    15 => "c:p",

    48 => "S:P",
    49 => "S:P",
    50 => "S:P",
    51 => "S:P",
    52 => "S:P",
    53 => "S:P",
    54 => "S:P",
    55 => "S:P",
    56 => "S:R",
    57 => "S:N",
    58 => "S:B",
    59 => "S:Q",
    60 => "S:-K",
    61 => "S:B",
    62 => "S:N",
    63 => "S:R"
  }.freeze

  PUCHI_SHOGI_VS_PUCHI_SHOGI_SQUARE = {
    0  => "s:r",
    1  => "s:n",
    2  => "s:b",
    3  => "s:q",
    4  => "s:-k",
    5  => "s:b",
    6  => "s:n",
    7  => "s:r",
    8  => "s:p",
    9  => "s:p",
    10 => "s:p",
    11 => "s:p",
    12 => "s:p",
    13 => "s:p",
    14 => "s:p",
    15 => "s:p",

    48 => "S:P",
    49 => "S:P",
    50 => "S:P",
    51 => "S:P",
    52 => "S:P",
    53 => "S:P",
    54 => "S:P",
    55 => "S:P",
    56 => "S:R",
    57 => "S:N",
    58 => "S:B",
    59 => "S:Q",
    60 => "S:-K",
    61 => "S:B",
    62 => "S:N",
    63 => "S:R"
  }.freeze

  PUCHI_SHOGI_VS_XIAOQI_SQUARE = {
    0  => "x:r",
    1  => "x:n",
    2  => "x:b",
    3  => "x:q",
    4  => "x:-k",
    5  => "x:b",
    6  => "x:n",
    7  => "x:r",
    8  => "x:p",
    9  => "x:p",
    10 => "x:p",
    11 => "x:p",
    12 => "x:p",
    13 => "x:p",
    14 => "x:p",
    15 => "x:p",

    48 => "S:P",
    49 => "S:P",
    50 => "S:P",
    51 => "S:P",
    52 => "S:P",
    53 => "S:P",
    54 => "S:P",
    55 => "S:P",
    56 => "S:R",
    57 => "S:N",
    58 => "S:B",
    59 => "S:Q",
    60 => "S:-K",
    61 => "S:B",
    62 => "S:N",
    63 => "S:R"
  }.freeze

  XIAOQI_VS_CHESS_SQUARE = {
    0  => "c:r",
    1  => "c:n",
    2  => "c:b",
    3  => "c:q",
    4  => "c:-k",
    5  => "c:b",
    6  => "c:n",
    7  => "c:r",
    8  => "c:p",
    9  => "c:p",
    10 => "c:p",
    11 => "c:p",
    12 => "c:p",
    13 => "c:p",
    14 => "c:p",
    15 => "c:p",

    48 => "X:P",
    49 => "X:P",
    50 => "X:P",
    51 => "X:P",
    52 => "X:P",
    53 => "X:P",
    54 => "X:P",
    55 => "X:P",
    56 => "X:R",
    57 => "X:N",
    58 => "X:B",
    59 => "X:Q",
    60 => "X:-K",
    61 => "X:B",
    62 => "X:N",
    63 => "X:R"
  }.freeze

  XIAOQI_VS_PUCHI_SHOGI_SQUARE = {
    0  => "s:r",
    1  => "s:n",
    2  => "s:b",
    3  => "s:q",
    4  => "s:-k",
    5  => "s:b",
    6  => "s:n",
    7  => "s:r",
    8  => "s:p",
    9  => "s:p",
    10 => "s:p",
    11 => "s:p",
    12 => "s:p",
    13 => "s:p",
    14 => "s:p",
    15 => "s:p",

    48 => "X:P",
    49 => "X:P",
    50 => "X:P",
    51 => "X:P",
    52 => "X:P",
    53 => "X:P",
    54 => "X:P",
    55 => "X:P",
    56 => "X:R",
    57 => "X:N",
    58 => "X:B",
    59 => "X:Q",
    60 => "X:-K",
    61 => "X:B",
    62 => "X:N",
    63 => "X:R"
  }.freeze

  XIAOQI_VS_XIAOQI_SQUARE = {
    0  => "x:r",
    1  => "x:n",
    2  => "x:b",
    3  => "x:q",
    4  => "x:-k",
    5  => "x:b",
    6  => "x:n",
    7  => "x:r",
    8  => "x:p",
    9  => "x:p",
    10 => "x:p",
    11 => "x:p",
    12 => "x:p",
    13 => "x:p",
    14 => "x:p",
    15 => "x:p",

    48 => "X:P",
    49 => "X:P",
    50 => "X:P",
    51 => "X:P",
    52 => "X:P",
    53 => "X:P",
    54 => "X:P",
    55 => "X:P",
    56 => "X:R",
    57 => "X:N",
    58 => "X:B",
    59 => "X:Q",
    60 => "X:-K",
    61 => "X:B",
    62 => "X:N",
    63 => "X:R"
  }.freeze
end
