# frozen_string_literal: true

require "pseudo_legal_move_tablebase/chess"
require "pseudo_legal_move_tablebase/puchi_shogi"
require "pseudo_legal_move_tablebase/xiaoqi"

module Sanqi
  class Tablebase
    attr_reader :db

    def initialize
      @db = chess.merge(puchi_shogi, xiaoqi)
    end

    def possibilities(piece:, source:, target:)
      Array(@db.dig(piece, source, target))
    end

    def inspect
      "<Sanqi::Tablebase #{@db.keys.sort.join(' ')}>"
    end

    private

    def chess
      ::PseudoLegalMoveTablebase::Chess::DB
    end

    def puchi_shogi
      ::PseudoLegalMoveTablebase::PuchiShogi::DB
    end

    def xiaoqi
      ::PseudoLegalMoveTablebase::Xiaoqi::DB
    end
  end
end
